OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Otkrivena je nova lokacija prijave",
    "More info about the suspicious IP address available on %s" : "Više informacija o sumnjivoj IP adresi dostupno je na %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Otkrivena je nova prijava u vaš račun. IP adresa %s klasificirana je kao sumnjiva. Ako ste to bili vi, možete zanemariti ovu poruku. U suprotnom biste trebali promijeniti zaporku.",
    "Open %s ↗" : "Otvori %s ↗",
    "Suspicious Login" : "Sumnjiva prijava",
    "New login detected" : "Otkrivena je nova prijava",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Otkrijte i upozorite na sumnjive IP adrese koje se prijavljuju u Nextcloud\n\t"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
